@@ -146,10 +146,11 @@ def config(filename):
     cfgfile = ConfigParser({ "here": os.path.dirname(cfgpath) })
     cfgfile.read(cfgpath)
 
-    if not cfgfile.has_section("app:main"):
-        print "%s is missing section [app:main]" % (filename)
+    cfg = {}
+    if cfgfile.has_section("app:main"):
+        cfg.update(cfgfile.items("app:main"))
 
-    return dict(cfgfile.items("app:main"))
+    return cfg
 
 class Command(object):
     """
@@ -209,8 +210,6 @@ class Command(object):
 
         if self.options.config:
             cfg = config(self.options.config)
-            if not cfg:
-                sys.exit(1)
             self.config.update(cfg)
 
     def setup_logging(self):
