@@ -150,8 +150,11 @@ class Graph(_Graph, _Common):
 
 
     def __init__(self, store="IOMemory", identifier=None, **kw):
-        if identifier is not None and not isinstance(identifier, Node):
-            identifier = URIRef(identifier)
+        if identifier is not None:
+            if not isinstance(identifier, Node):
+                identifier = URIRef(identifier)
+        else:
+            identifier = BNode()
         if __rdflib_version__ == 2:
             super(Graph, self).__init__(store, identifier)
         else:
